//  Magnetic Field Right Hand Rule
//  Last Modified 07/14/2016
//  Dr. Steven Sahyun
//  Chris Marshall
//  UW-Whitewater
/*
    This code will represent a 3D model of the direction of the magnetic field given a directional current.  
*/

include<B_Field_Model_Modules.scad>;

ilength = 40; // this is the length for the current arm
//  NOTE: All lengths must be greater than 20
normalx = 6; // this is the "x" value for the "y" and "i" arms
normaly = 6; // this is the "y" value for the "x" and "i" arms
normalz = 4; // this is the "z" value for the "y" and "i" arms
itext = "i"; // this text can be changed to suit whatever need
btext = "B"; // this text can be changed to suit whatever need
rad = 30; // this is the raduis of the large cylinder 
thickness = 2.5; // this is the radius of the smaller, subtracted cylinder
baseh = normalz * 0.4;// the height of the base
fudge = -0.5; //a value to make files fit well together

ir = 5.5;// Radius of the current arm

//Braille Dot Spacing distances in mm
radius = 1.0;
dotspacing = 2.4;
cellspacing = 6.2;

ring(rad, thickness, normalz); //Magnetic Field Ring

cylinder(h = baseh, r = rad+(thickness/2), center = false, $fn = 40); //Base
cylinder(h = ilength, r = ir, center = false, $fn = 50);//Current Cylinder
translate([0,0,ilength]){
    cylinder(h = ilength*0.25, r1 = ir+1, r2 = 0, center = false, $fn = 70);
}//Current Arrow

//Arrows
translate([rad+fudge-normalx, -ir, 0]){
    triangle(normalx*2, normalx*2, normalz*1.5);
}
translate([ir, rad-normalx+fudge, 0]){
    rotate([0,0,90]){
        triangle(normalx*2, normalx*2, normalz*1.5);}
}
translate([-(rad-normalx+fudge), ir, 0]){
    rotate([0,0,180]){
        triangle(normalx*2, normalx*2, normalz*1.5);}
}
translate([-ir, -(rad-normalx+fudge), 0]){
    rotate([0,0,270]){
        triangle(normalx*2, normalx*2, normalz*1.5);}
}

//Labels
translate([-ir, -rad*0.7, 0]){
    rotate([0,0,90]){
        letter(baseh*1.5, btext, 6);}
}
translate([rad*0.7, -ir, 0]){
    rotate([0,0,180]){
        letter(baseh*1.5, btext, 6);}
}
translate([ir, rad*0.7, 0]){
    rotate([0,0,270]){
        letter(baseh*1.5, btext, 6);}
}
translate([-rad*0.7, ir, 0]){
    rotate([0,0,360]){
        letter(baseh*1.5, btext, 6);}
}   
translate([ir+1, ir/4, ilength*0.7]){
    rotate([0,270,0]){
        letter(ir, itext, 6);}
}//Current Label

//Braille Labels
for (a = [0:90:270]){
    rotate([0,0,a]){
        b();}
    }//"B" Labels
translate([-ir, ir/4, ilength*0.8]){
    rotate([0,90,180]){
        drawtext("i");}
    }//Current "i" Label
translate([-ir+1, -ir/3, ilength*0.55]){
    rotate([45, 0, 90]){
        cube([ir*0.9, 3, 1], false);}
}//Bottom braille bar for current